@@ -23,7 +23,6 @@
 #' hits based on the category.
 #'
 #' @rdname rank_sites_DT
-#' @importFrom stats median
 #' @examples
 #' # This is the example workflow:
 #' path_to_tox <- system.file("extdata", package = "toxEval")
@@ -51,8 +50,7 @@ rank_sites_DT <- function(chemical_summary,
                           mean_logic = FALSE,
                           sum_logic = TRUE,
                           hit_threshold = 0.1) {
-  Bio_category <- Class <- EAR <- maxEAR <- sumEAR <- value <- calc <- chnm <- choice_calc <- n <- nHits <- site <- ".dplyr"
-
+  
   match.arg(category, c("Biological", "Chemical Class", "Chemical"))
 
   statsOfColumn <- rank_sites(
@@ -140,17 +138,15 @@ rank_sites <- function(chemical_summary,
                        hit_threshold = 0.1,
                        mean_logic = FALSE,
                        sum_logic = TRUE) {
-  sumEAR <- nHits <- n <- calc <- value <- choice_calc <- name <- ".dplyr"
-  chnm <- Class <- Bio_category <- site <- EAR <- maxEAR <- ".dplyr"
 
   siteToFind <- unique(chemical_summary$shortName)
 
   if (category == "Chemical") {
-    chemical_summary <- mutate(chemical_summary, category = chnm)
+    chemical_summary <- dplyr::mutate(chemical_summary, category = chnm)
   } else if (category == "Chemical Class") {
-    chemical_summary <- mutate(chemical_summary, category = Class)
+    chemical_summary <- dplyr::mutate(chemical_summary, category = Class)
   } else {
-    chemical_summary <- mutate(chemical_summary, category = Bio_category)
+    chemical_summary <- dplyr::mutate(chemical_summary, category = Bio_category)
   }
 
   chemical_summary <- dplyr::select(chemical_summary, -Class, -Bio_category, -chnm)
@@ -163,28 +159,28 @@ rank_sites <- function(chemical_summary,
 
   if (!sum_logic) {
     statsOfColumn <- chemical_summary %>%
-      group_by(site, date, category) %>%
-      summarize(
+      dplyr::group_by(site, date, category) %>%
+      dplyr::summarize(
         sumEAR = max(EAR),
         nHits = sum(sumEAR > hit_threshold)
       ) %>%
-      group_by(site, category) %>%
-      summarise(
+      dplyr::group_by(site, category) %>%
+      dplyr::summarise(
         maxEAR = ifelse(mean_logic, mean(sumEAR), max(sumEAR)),
-        freq = sum(nHits > 0) / n()
+        freq = sum(nHits > 0) / dplyr::n()
       ) %>%
       data.frame()
   } else {
     statsOfColumn <- chemical_summary %>%
-      group_by(site, date, category) %>%
-      summarise(
+      dplyr::group_by(site, date, category) %>%
+      dplyr::summarise(
         sumEAR = sum(EAR),
         nHits = sum(sumEAR > hit_threshold)
       ) %>%
-      group_by(site, category) %>%
-      summarise(
+      dplyr::group_by(site, category) %>%
+      dplyr::summarise(
         maxEAR = ifelse(mean_logic, mean(sumEAR), max(sumEAR)),
-        freq = sum(nHits > 0) / n()
+        freq = sum(nHits > 0) / dplyr::n()
       ) %>%
       data.frame()
   }
